* STATA Program 
* copyright C 2008 by A. Colin Cameron and Pravin K. Trivedi 
* used for "Microeconometrics Using Stata" 
* database LSMS 2007 serbia
* by A. Colin Cameron and Pravin K. Trivedi (2008)
* adapted by Marko Vladisavljevic (Faculty of Ecnomics, University of Belgrade)
cd "C:\Users\Visitor\Dropbox\fakultet\master"
capture log close
estimates clear
log using beer.txt, text replace
use beer, clear

********** SETUP **********
* Dependent variable is 
 * qbeer - quantity of beer
 * dq - takes value 1 if hh has beer consumption
* Main independent variables is 
 * pbeer - price of beer
	* income_ae - income per adult equivalent
*Regressors are household head level:
 * age_hh - age of the hh 
 * female_hh - gender of the hh - 1 for females, zero otherwise
 * edu_hh - level of education of the household head (1-primary; 2 secondary; 3 tertiary)
 * hhsize - household size
 * numkids0 - number of chindren aged 0 to 6 
 * numkids7 - number of chindren aged 7 to 14 
	* region2 - region fixed effects
	
* Raw data summary
global xlist hhsize numkids0 numkids7 ///
			 i.region2 i.female_hh age_hh i.edu_hh
sum qbeer pbeer income_ae $xlist

* Detailed summary to show skewness and kurtosis
summarize qbeer, detail

* Summary for positives only
summarize qbeer if qbeer >0, detail 
histogram qbeer if qbeer >0 
*=> descriptive statistics suggest that the distribution is right-skewed

* ta 
ta dq
*=> share of hosueholds with zero expenditures on beer is substaintial: 55%

************ 16.4 TOBIT FOR LOGNORMAL DATA
* logarithms
gen lnq = ln(qbeer)
sum lnq
histogram lnq

* as ln(0) is not defined we use a small value lower than the lowest log quantity to "trick" stata into treating this as a censored variable
replace lnq = -4.306764 - 0.000001 if lnq == .
sum lnq
histogram lnq

* calculate natural log of price and income needed for estimation
gen lnp = ln(pbeer)
gen lny = ln(income_ae)

* tobit estimate
tobit lnq lnp lny $xlist, ll
* => no direct interpretation of the coefficent, as censored values do not represent lower unobserved values, but actual zero consumption (corner solution)
* => we need marginal effects
* => addtional explanation if needed: different prediction options 
predict xb, xb
predict ystar, ystar(-4.306765,.)
sum lnq xb ystar 
* the best fit of the model is for ystar() option, as tobit linear prediction would signficantly underestimate the minimum value


* marginal effects
margins, dydx(*) predict(ystar(-4.306765,.)) post
* note: minimum value in y star is not zero, but its going to be the value that we created in row 53 (replace lnq = -4.306764 - 0.000001 if lnq == .), so that this represents ln(0)

* INTERPRETATION OF THE MARGINAL EFFECTS: 
* => estimated price elasticity is -0.34, i.e. according to tobit model, a price increase of 1% would decrease the quantity of the beer consumed by 0.34%
* => estimated income elasticity is 0.23, i.e. according to tobit model, a income increase of 1% would increase the quantity of the beer consumed by 0.23%
* => a household with additional house member increaes the quantity of the beer consumed by 19.7%
* => female headed households consume less beer than male headed households by 57.9%

* USE OUTREG2 TO STORE RESULTS AND EASILY TRANSFER TO EXCEL
* ssc install outreg2 // if it does not work on your computer
outreg2 using ln, ctitle(tobit) dec(3) replace label excel



************ 16.5 TWO-PART MODEL IN LOGS

******************************
* Part 1 of the two-part model
probit dq lnp lny $xlist, nolog
* marginal effects 
margins, eydx(*) post atmean // not in the book, but nesseary for interpration. We use semi-elasticity (eydx) estimate here as we use this form of marginal effects in the Part 2 of the model (intepretation of effects in lnq equation is % change) 

* INTERPRETATION OF THE MARGINAL EFFECTS: 
* => estimated coefficent for price is -0.13, i.e. a price increase of 1% would decrease the likelihood of beer consumption by 0.13% (prevalence price elasticity). However the effect is not significant, indicating that the price of beer does not affect the decision to drink or not to drink beer
* => estimated coefficent for income is 0.18, i.e. , an income increase of 1% would increase the likelihood of beer consumption by 0.18% (prevalence income elasticity)
* => a household with additional house member has higher likelihood to consume beer by 22.1%
* => female headed households have lower likelihood of beer consumption than male headed households by 51.4%
outreg2 using ln, ctitle(firstpart) dec(3) label excel

******************************
* Part 2 of the two-part model
regress lnq lnp lny $xlist if dq==1
outreg2 using ln, ctitle(secondpart) dec(3) label excel
* => results are marginal effects as this is ols

* INTERPRETATION OF THE MARGINAL EFFECTS: 
* => estimated coefficent for price is -0.61, i.e. a price increase of 1% would decrease conditional demand for beer by 0.61% (conditional demand price elasticity). Meaning of the conditional: within the sample of those who have positive consumption on beer. The effect is significant, indicating that the price of beer affects the decision of how much beer to drink.
* => estimated coefficent for income is 0.10, i.e. , an income increase of 1% would increase the conditional demand for beer by 0.10%
* => a household with additional house member has lower conditional demand for beer by 16.3%
* => female headed households have lower lower conditional demand for beer than male headed households by 12.6%


* Joint estimation from the two-part model
// not in the book, we use twopm command to calculate the overall effects from the two parts of the model.
 
*ssc install twopm, replace /* install before use */

twopm qbeer lnp lny $xlist, firstpart(probit) secondpart(regress, log) // ambexp is entered here instead of lny, as we suggest to the program that the variable in the second part should be in log form in the part of the command secondpart (., log). 

margins, predict(duan) eydx(*) post // We use semi-elasticity (eydx) estimate here as we use this form of marginal effects in the Part 2 of the model (intepretation of effects in lnq equation is % change).  However note that the interpretation of the coefficent is elasticity as price and income are in log forms

* => estimated elasticity for price is -0.74, i.e. a price increase of 1% would decrease demand for beer (beer expenditures) by 0.74% 
* => estimated elasticity for income is 0.28, i.e. , an income increase of 1% would increase demand for beer (beer expenditures) by 0.10%
* => a household with additional house member has higher demand for beer (beer expenditures) by 6.4%
* => female headed households have lower lower conditional demand for beer than male headed households by 64.7%

outreg2 using ln, ctitle(twopm) dec(3) label excel
* NOTE THAT SUM OF THE ESTIMATED ELASTICITIES FROM THE TWO PARTS OF THE MODEL ARE APROXIMATELY EQUAL TO THE ONE ESTIMATE WITH TWOPM COMMAND


************ 16.6 SELECTION MODEL
* lets assume that only these variables are the determinats of amount spent on beer
global xlist hhsize i.region2 i.female_hh age_hh i.edu_hh

* OLS with new covariates
regress lnq lnp lny $xlist if dq==1
outreg2 using heckman, ctitle(lnq) replace dec(3) label excel
* => results are marginal effects as this is ols

* INTERPRETATION OF THE MARGINAL EFFECTS: 
* => estimated coefficent for price is -0.61, i.e. a price increase of 1% would decrease conditional demand for beer by 0.61% (conditional demand price elasticity). Meaning of the conditional: within the sample of those who have positive consumption on beer. The effect is significant, indicating that the price of beer affects the decision of how much beer to drink.
* => estimated coefficent for income is 0.10, i.e. , an income increase of 1% would increase the conditional demand for beer by 0.10%
* => a household with additional house member has lower conditional demand for beer by 16.3%
* => female headed households have lower lower conditional demand for beer than male headed households by 12.6%

* Heckman MLE without exclusion restrictions - first heckman equation is identified via funcitional form of the model
heckman lnq lnp lny $xlist, select(dq = lnp lny $xlist) nolog
outreg2 using heckman, dec(3) label excel addstat(rho, `e(rho)', sig, `e(p_c)')
* => estimated coefficent for price is -0.67, i.e. a price increase of 1% would decrease conditional demand for beer by 0.67% (conditional demand price elasticity). Meaning of the conditional: within the sample of those who have positive consumption on beer. The effect is significant, indicating that the price of beer affects the decision of how much beer to drink.
* => estimated coefficent for income is 0.18, i.e. , an income increase of 1% would increase the conditional demand for beer by 0.18%
* => a household with additional house member has lower conditional demand for beer by 9.3%
* => female headed households have lower lower conditional demand for beer than male headed households by 38.7%

* Heckman MLE with exclusion restriction - first heckman equation is identified via additional two variables (number of kids aged 0 to 6 and aged 7 to 14)
heckman lnq lnp lny $xlist, select(dq = lnp lny $xlist numkids0 numkids7) nolog
outreg2 using heckman, dec(3) label excel addstat(rho, `e(rho)', sig, `e(p_c)')
* => estimated coefficent for price is -0.65, i.e. a price increase of 1% would decrease conditional demand for beer by 0.65% (conditional demand price elasticity). Meaning of the conditional: within the sample of those who have positive consumption on beer. The effect is significant, indicating that the price of beer affects the decision of how much beer to drink.
* => estimated coefficent for income is 0.18, i.e. , an income increase of 1% would increase the conditional demand for beer by 0.18%
* => a household with additional house member has lower conditional demand for beer by 10.5%
* => female headed households have lower lower conditional demand for beer than male headed households by 33.2%

********** CLOSE OUTPUT
capture log close
clear
exit


