* STATA Program 
* copyright C 2008 by A. Colin Cameron and Pravin K. Trivedi 
* used for "Microeconometrics Using Stata" 
* by A. Colin Cameron and Pravin K. Trivedi (2008)
* adapted by Marko Vladisavljevic (Faculty of Ecnomics, University of Belgrade)
cd "C:\Users\Visitor\Dropbox\fakultet\master"
capture log close
estimates clear
log using mus16p1tobit.txt, text replace
use mus16data1.dta, clear // open data

************ 16.3 TOBIT MODEL EXAMPLE
* Dependent variable is 
    *ambexp  - Ambulatory medical expenditures (excluding outpatient mental) 
	*dy  	 1 if ambexp > 0 and 0 otherwise
*Regressors are 
    *age - age in years/10 
    *female - 1 for females, zero otherwise
    *educ - years of schooling of decision maker
    *blhisp - either black or Hispanic (hispanic = 1)
    *totchr - number of chronic diseases
    *ins - Health type insurance (PPO=0; HMO = 1)
	
* Raw data summary
sum ambexp age i.female educ i.blhisp totchr i.ins 
global xlist age i.female educ i.blhisp totchr i.ins   //Define regressor list $xlist

* Detailed summary to show skewness and kurtosis
summarize ambexp, detail

* Summary for positives only
summarize ambexp if ambexp >0, detail
 
* number of people who have positive expenditures is 2,802
tab dy

*histogram ambexp
histogram ambexp if ambexp >0
* => the distribution is right skewed, so we need to apply log transformation

**** NOT IN THE BOOK *************
* 1) OLS - wrong model
reg ambexp $xlist
estimates store ols
outreg2 using est, ctitle(OLS) dec(0) side stats(coef ci_low ci_high) replace  label 
* predict estimates 
predict yhat_ols
* graphs
scatter yhat_ols ambexp  
* summary statistics
gen ambexp_c = ambexp
recode ambexp_c (0=.)
sum yhat_ols ambexp ambexp_c
**** END NOT IN THE BOOK *********

* 2) Tobit analysis for ambexp using all expenditures
tobit ambexp $xlist, ll(0) 
outreg2 using est, ctitle(tobit) dec(0) side stats(coef ci_low ci_high) label excel

* Tobit prediction and summary
predict yhat_tobit_xb, xb
predict yhat_tobit, ystar(0,.)
summarize ambexp yhat_ols yhat_tobit_xb yhat_tobit 

scatter yhat_tobit ambexp // not in the book


* marginal effeects
* ME without censoring on E(y|x)
margins, dydx(*) predict(ystar(0,.)) post
outreg2 using est, ctitle(tobit, conditional) dec(0) side stats(coef ci_low ci_high) label excel

drop yhat_tobit*

************ 16.4 TOBIT FOR LOGNORMAL DATA
* IN THE BOOK MAKING VARIABLES FOR TOBIT ESTIMATION IN LOGS
* Dependent variable is 
*   ambexp   Ambulatory medical expenditures (excluding dental and outpatient mental) 
*   lambexp  Ln(ambexp) given ambexp > 0 ; missing otherwise
*   dy  	 1 if ambexp > 0 and 0 otherwise
*   lny 	 Ln(ambexp) if ambexp>0 and 0.000001 if ambexp=0  

* dummy variable for positive expenditures
tab dy

* Summary of log(expenditures) for positives only
summarize lambexp, detail
* Summary of log(expenditures) 
summarize lny, detail

* OLS, not tobit
regress lny $xlist, noheader
outreg2 using ln, ctitle(ols) dec(3) side  replace label excel

* Now do tobit on lny and calculate threshold and lambda
tobit lny $xlist, ll 
outreg2 using ln, ctitle(tobit) dec(3) side   label excel

predict yhat_tobit, ystar(-0.000001,.)
sum yhat_tobit*

margins, dydx(*) predict(ystar(-0.000001,.)) post 
outreg2 using ln, ctitle(tobit, conditional) dec(3) side   label excel

* show that tobit prediction results in non-zero predictions
scatter yhat_tobit lny 

************ 16.5 TWO-PART MODEL IN LOGS
* Part 2 of the two-part model
regress lny $xlist if dy==1
outreg2 using ln, ctitle(reg) dec(3)    label excel

* Part 1 of the two-part model
probit dy $xlist, nolog

// not in the book, we use semi-elasticity (eydx) estimate here as we use this form of marginal effects in the Part 2 of the model (intepretation of effects in lny equation is % change)
margins, eydx(*) post atmean 
outreg2 using ln, ctitle(probit) dec(3)   label excel

// not in the book, we use twopm command to calculate the overall effects from the two parts of the model. Again we use eydx form of the marginal effects
*ssc install twopm, replace /* install befor use */
twopm ambexp $xlist, firstpart(probit) secondpart(regress, log) // ambexp is entered here instead of lny, as we suggest to the program that the variable in the second part should be in log form in the part of the command secondpart (., log)
margins, predict(duan) eydx(*) post atmean
outreg2 using ln, ctitle(twopm) dec(3)  label excel

************ 16.6 SELECTION MODEL

* OLS 
regress lny $xlist if dy==1
outreg2 using heckman, ctitle(lny) replace dec(3) label excel

* Heckman MLE without exclusion restrictions
heckman lny $xlist, select(dy = $xlist) nolog
outreg2 using heckman,  dec(3) label excel addstat(rho, `e(rho)', sig, `e(p_c)')

* Heckman 2-step without exclusion restrictions
heckman lny $xlist, select(dy = $xlist) twostep
 outreg2 using heckman,  dec(3) label excel addstat(rho, `e(rho)', sig, `e(p)')

* Heckman MLE with exclusion restriction
heckman lny $xlist, select(dy = $xlist income) nolog
outreg2 using heckman,  dec(3) label excel addstat(rho, `e(rho)', sig, `e(p_c)')

// Following not included in book
* Heckman 2-step with exclusion restrictions
heckman lny $xlist, select(dy = $xlist income) twostep
 outreg2 using heckman,  dec(3) label excel addstat(rho, `e(rho)', sig, `e(p)')


********** CLOSE OUTPUT
capture log close
clear
exit


